@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from covsirphy.util.error import UnExecutedError
+from covsirphy.util.error import UnExecutedError, deprecate
 from covsirphy.util.argument import find_args
 from covsirphy.util.evaluator import Evaluator
 from covsirphy.util.term import Term
@@ -34,13 +34,14 @@ class ParamTracker(Term):
         tau (int or None): tau value [min]
     """
 
+    @deprecate("", new="ODEHandler", version="2.19.1-zeta-fu1")
     def __init__(self, record_df, phase_series, area=None, tau=None):
         # Phase series
         self._series = self._ensure_instance(phase_series, PhaseSeries, name="phase_series")
         # Records
         self._ensure_dataframe(record_df, name="record_df", columns=self.SUB_COLUMNS)
-        df = record_df.loc[record_df[self.DATE] >= self.date_obj(phase_series.first_date)]
-        self.record_df = df.loc[df[self.DATE] <= self.date_obj(phase_series.last_date)]
+        df = record_df.loc[record_df[self.DATE] >= self._ensure_date(phase_series.first_date)]
+        self.record_df = df.loc[df[self.DATE] <= self._ensure_date(phase_series.last_date)]
         # Area name
         self.area = area or ""
         # Tau value
