@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from pathlib import Path
 import numpy as np
 import pandas as pd
 from covsirphy.util.error import SubsetNotFoundError, deprecate
@@ -21,54 +20,30 @@ class JHUData(CleaningBase):
                 reset index
             Columns
                 - Date: Observation date
-                - ISO3: ISO3 code (optional)
+                - ISO3: ISO3 code
                 - Country: country/region name
                 - Province: province/prefecture/state name
                 - Confirmed: the number of confirmed cases
                 - Fatal: the number of fatal cases
                 - Recovered: the number of recovered cases
-                - Population: population values (optional)
+                - Population: population values
         citation (str or None): citation or None (empty)
 
     Note:
         Either @filename (high priority) or @data must be specified.
+
+    Note:
+        The number of infected cases will be (re-)calculated when data cleaning automatically.
     """
-    # Required/optinal cols of raw dataset
-    REQUIRED_COLS = [
-        CleaningBase.DATE, CleaningBase.COUNTRY, CleaningBase.PROVINCE,
-        CleaningBase.C, CleaningBase.F, CleaningBase.R,
-    ]
-    OPTINAL_COLS = [CleaningBase.ISO3, CleaningBase.N]
-    # Columns of self._cleaned_df
-    RAW_COLS = [
+    # For JHUData.from_dataframe()
+    _RAW_COLS_DEFAULT = [
         CleaningBase.DATE, CleaningBase.ISO3, CleaningBase.COUNTRY, CleaningBase.PROVINCE,
         CleaningBase.C, CleaningBase.CI, CleaningBase.F, CleaningBase.R, CleaningBase.N
     ]
-    # Columns of self.cleaned()
-    CLEANED_COLS = [
-        CleaningBase.DATE, CleaningBase.COUNTRY, CleaningBase.PROVINCE,
-        CleaningBase.C, CleaningBase.CI, CleaningBase.F, CleaningBase.R,
-    ]
-    # Columns of self.subset()
-    SUBSET_COLS = [
-        CleaningBase.DATE, CleaningBase.C, CleaningBase.CI,
-        CleaningBase.F, CleaningBase.R, CleaningBase.S,
-    ]
 
     def __init__(self, filename=None, data=None, citation=None):
-        # Raw data
-        self._raw = self._parse_raw(filename, data, self.REQUIRED_COLS, optional_cols=self.OPTINAL_COLS)
-        self._raw[self.CI] = None
-        # Data cleaning
-        self._cleaned_df = pd.DataFrame(columns=self.RAW_COLS) if self._raw.empty else self._cleaning()
-        # Citation
-        self._citation = citation or ""
-        # Directory that save the file
-        if filename is None:
-            self._dirpath = Path("input")
-        else:
-            Path(filename).parent.mkdir(exist_ok=True, parents=True)
-            self._dirpath = Path(filename).resolve().parent
+        variables = [self.C, self.CI, self.F, self.R, self.N]
+        super().__init__(filename=filename, data=data, citation=citation, variables=variables)
         # Recovery period
         self._recovery_period = None
 
@@ -89,7 +64,7 @@ class JHUData(CleaningBase):
         Return the cleaned dataset.
 
         Args:
-            kwargs: keword arguments will be ignored.
+            kwargs: keyword arguments will be ignored
 
         Returns:
             pandas.DataFrame
@@ -97,19 +72,21 @@ class JHUData(CleaningBase):
                     reset index
                 Columns
                     - Date (pandas.Timestamp): Observation date
+                    - ISO3: ISO3 code
                     - Country (pandas.Category): country/region name
                     - Province (pandas.Category): province/prefecture/state name
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
                     - Recovered (int): the number of recovered cases
+                    - Population: population values
         """
         if "population" in kwargs.keys():
             raise ValueError(
                 "@population was removed in JHUData.cleaned(). Please use JHUData.subset()")
         df = self._cleaned_df.copy()
         df[self.CI] = (df[self.C] - df[self.F] - df[self.R]).astype(np.int64)
-        return df.loc[:, self.CLEANED_COLS]
+        return df
 
     def _cleaning(self):
         """
@@ -130,7 +107,7 @@ class JHUData(CleaningBase):
                     - Recovered (int): the number of recovered cases
                     - Population (int): population values or 0 (when raw data is 0 values)
         """
-        df = self._raw.loc[:, self.RAW_COLS]
+        df = self._raw.loc[:, self._raw_cols]
         # Datetime columns
         df[self.DATE] = pd.to_datetime(df[self.DATE]).dt.round("D")
         try:
@@ -154,8 +131,9 @@ class JHUData(CleaningBase):
         df = pd.concat([without_c_chn_df, p_chn_df], ignore_index=True)
         # Update data types to reduce memory
         df[self.AREA_ABBR_COLS] = df[self.AREA_ABBR_COLS].astype("category")
-        return df.loc[:, self.RAW_COLS]
+        return df.loc[:, self._raw_cols]
 
+    @deprecate("JHUData.replace()", version="2.21.0-xi-fu1")
     def replace(self, country_data):
         """
         Replace a part of cleaned dataset with a dataframe.
@@ -179,7 +157,7 @@ class JHUData(CleaningBase):
         new[self.N] = new.loc[:, self.N] if self.N in new else None
         new = new.set_index([self.COUNTRY, self.PROVINCE, self.DATE])
         new.update(df.set_index([self.COUNTRY, self.PROVINCE, self.DATE]).loc[:, [self.N]])
-        new = new.reset_index().loc[:, self.RAW_COLS]
+        new = new.reset_index().loc[:, self._raw_cols]
         # Calculate Infected
         new[self.CI] = (new[self.C] - new[self.F] - new[self.R]).astype(np.int64)
         # Remove the data in the country from JHU dataset
@@ -220,7 +198,7 @@ class JHUData(CleaningBase):
             return super().subset(
                 country=country, province=province, start_date=start_date, end_date=end_date)
         except SubsetNotFoundError:
-            return pd.DataFrame(columns=self.RAW_COLS)
+            return pd.DataFrame(columns=self._raw_cols)
 
     def _calculate_susceptible(self, subset_df, population):
         """
@@ -261,11 +239,12 @@ class JHUData(CleaningBase):
             df[self.S] = df[self.S].astype(np.int64)
         except ValueError:
             return df.loc[:, [self.DATE, self.C, self.CI, self.F, self.R]]
-        return df.loc[:, self.SUBSET_COLS]
+        return df.loc[:, [self.DATE, self.C, self.CI, self.F, self.R, self.S]]
 
-    def subset(self, country, province=None, start_date=None, end_date=None, population=None):
+    def subset(self, country, province=None, start_date=None, end_date=None,
+               population=None, recovered_min=1):
         """
-        Return the subset of dataset with Recovered > 0.
+        Return the subset of dataset.
 
         Args:
             country (str): country name or ISO3 code
@@ -273,6 +252,7 @@ class JHUData(CleaningBase):
             start_date (str or None): start date, like 22Jan2020
             end_date (str or None): end date, like 01Feb2020
             population (int or None): population value
+            recovered_min (int): minimum number of recovered cases records must have
 
         Returns:
             pandas.DataFrame
@@ -300,15 +280,17 @@ class JHUData(CleaningBase):
                 start_date=start_date, end_date=end_date)
         # Calculate Susceptible
         df = self._calculate_susceptible(subset_df, population)
-        # Select records where Recovered > 0
-        df = df.loc[df[self.R] > 0, :].reset_index(drop=True)
+        # Select records where Recovered >= recovered_min
+        recovered_min = self._ensure_natural_int(recovered_min, name="recovered_min", include_zero=True)
+        df = df.loc[df[self.R] >= recovered_min, :].reset_index(drop=True)
         if df.empty:
             raise SubsetNotFoundError(
                 country=country, country_alias=country_alias, province=province,
-                start_date=start_date, end_date=end_date, message="with 'Recovered > 0'") from None
+                start_date=start_date, end_date=end_date,
+                message=f"with 'Recovered >= {recovered_min}'") from None
         return df
 
-    @ deprecate("JHUData.to_sr()", version="2.17.0-zeta")
+    @deprecate("JHUData.to_sr()", version="2.17.0-zeta")
     def to_sr(self, country, province=None,
               start_date=None, end_date=None, population=None):
         """
@@ -339,7 +321,9 @@ class JHUData(CleaningBase):
             start_date=start_date, end_date=end_date, population=population)
         return subset_df.set_index(self.DATE).loc[:, [self.R, self.S]]
 
-    @ classmethod
+    @classmethod
+    @deprecate("JHUData.from_dataframe()", new="DataLoader.read_dataframe()",
+               version="2.21.0-xi-fu1", ref="https://lisphilar.github.io/covid19-sir/markdown/LOADING.html")
     def from_dataframe(cls, dataframe, directory="input"):
         """
         Create JHUData instance using a pandas dataframe.
@@ -368,7 +352,7 @@ class JHUData(CleaningBase):
         df[cls.N] = df[cls.N] if cls.N in df else 0
         instance = cls()
         instance.directory = str(directory)
-        instance._cleaned_df = cls._ensure_dataframe(df, name="dataframe", columns=cls.RAW_COLS)
+        instance._cleaned_df = cls._ensure_dataframe(df, name="dataframe", columns=cls._RAW_COLS_DEFAULT)
         return instance
 
     def total(self):
@@ -429,7 +413,7 @@ class JHUData(CleaningBase):
             if not self.subset_complement(country=country, **kwargs)[0].empty]
         return sorted(raw_ok_set | set(comp_ok_list))
 
-    @ deprecate("JHUData.calculate_closing_period()")
+    @deprecate("JHUData.calculate_closing_period()")
     def calculate_closing_period(self):
         """
         Calculate mode value of closing period, time from confirmation to get outcome.
